# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from asteroid_odyssey.models.agents_graph_models_nodes_properties_iris_playwright_script_properties import AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties
from typing import Optional, Set
from typing_extensions import Self

class AgentsGraphModelsNodesPropertiesIrisProperties(BaseModel):
    """
    AgentsGraphModelsNodesPropertiesIrisProperties
    """ # noqa: E501
    type: StrictStr
    instructions: StrictStr
    tools: List[StrictStr]
    snapshot_compression: StrictBool
    temperature: Union[StrictFloat, StrictInt]
    batch_actions: StrictBool
    playwright_script_properties: Optional[AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties] = None
    learn_and_compile: Optional[StrictBool] = None
    model: StrictStr
    __properties: ClassVar[List[str]] = ["type", "instructions", "tools", "snapshot_compression", "temperature", "batch_actions", "playwright_script_properties", "learn_and_compile", "model"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['iris']):
            raise ValueError("must be one of enum values ('iris')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsNodesPropertiesIrisProperties from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of playwright_script_properties
        if self.playwright_script_properties:
            _dict['playwright_script_properties'] = self.playwright_script_properties.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsNodesPropertiesIrisProperties from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "instructions": obj.get("instructions"),
            "tools": obj.get("tools"),
            "snapshot_compression": obj.get("snapshot_compression"),
            "temperature": obj.get("temperature"),
            "batch_actions": obj.get("batch_actions"),
            "playwright_script_properties": AgentsGraphModelsNodesPropertiesIrisPlaywrightScriptProperties.from_dict(obj["playwright_script_properties"]) if obj.get("playwright_script_properties") is not None else None,
            "learn_and_compile": obj.get("learn_and_compile"),
            "model": obj.get("model")
        })
        return _obj


