# coding: utf-8

"""
    Agent Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from asteroid_odyssey.models.agents_graph_models_type_input_method import AgentsGraphModelsTypeInputMethod
from typing import Optional, Set
from typing_extensions import Self

class AgentsGraphModelsSettings(BaseModel):
    """
    Configuration settings for workflow execution
    """ # noqa: E501
    max_iterations: StrictInt = Field(description="Maximum number of iterations")
    viewport_width: StrictInt = Field(description="Browser viewport width in pixels")
    viewport_height: StrictInt = Field(description="Browser viewport height in pixels")
    trim_screenshots: StrictBool = Field(description="Whether to trim screenshots")
    max_timeout_mins: StrictInt = Field(description="Maximum timeout in minutes")
    type_input_method: AgentsGraphModelsTypeInputMethod = Field(description="Text input method for browser automation")
    summarise: Optional[StrictBool] = Field(default=None, description="Whether to summarize execution results")
    new_agent_loop: Optional[StrictBool] = Field(default=None, description="Whether to use the new agent loop for execution (admin-only setting)")
    __properties: ClassVar[List[str]] = ["max_iterations", "viewport_width", "viewport_height", "trim_screenshots", "max_timeout_mins", "type_input_method", "summarise", "new_agent_loop"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AgentsGraphModelsSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "max_iterations": obj.get("max_iterations"),
            "viewport_width": obj.get("viewport_width"),
            "viewport_height": obj.get("viewport_height"),
            "trim_screenshots": obj.get("trim_screenshots"),
            "max_timeout_mins": obj.get("max_timeout_mins"),
            "type_input_method": obj.get("type_input_method"),
            "summarise": obj.get("summarise"),
            "new_agent_loop": obj.get("new_agent_loop")
        })
        return _obj


